==> kbibtex-trinity_14.0.4.orig.tar.xz: kbibtex-trinity-14.0.4/src/webquerycsb.h <==
/***************************************************************************
 *   Copyright (C) 2004-2009 by Thomas Fischer                             *
 *   fischer@unix-ag.uni-kl.de                                             *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/
#ifndef KBIBTEXWEBQUERYCSB_H
#define KBIBTEXWEBQUERYCSB_H

#include <tdeio/job.h>

#include <fileimporterbibtex.h>
#include <webquery.h>

class TQSpinBox;
class TQCheckBox;

class KLineEdit;
class KComboBox;

namespace KBibTeX
{
    /**
     @author Thomas Fischer <fischer@unix-ag.uni-kl.de>
    */
    class WebQueryCSBWidget : public WebQueryWidget
    {
        Q_OBJECT
    public:
        WebQueryCSBWidget( TQWidget *parent, const char *name = 0 );

        KComboBox *comboBoxField;
        TQCheckBox *checkBoxYear;
        KComboBox *comboBoxYear;
        TQSpinBox *spinBoxYear;
        KComboBox *comboBoxSortBy;
        TQCheckBox *checkBoxOnlinePapersOnly;

    protected:
        virtual void init();

    private slots:
        void slotYearCheckToggled();
    };


    /**
     @author Thomas Fischer <fischer@unix-ag.uni-kl.de>
    */
    class WebQueryCSB : public WebQuery
    {
        Q_OBJECT
    public:
        WebQueryCSB( TQWidget* parent );
        virtual ~WebQueryCSB();

        void query();

        TQString title();
        TQString disclaimer();
        TQString disclaimerURL();

        WebQueryWidget *widget();

    protected:
        void cancelQuery() { /* nothing */ };

    private:
        BibTeX::FileImporterBibTeX *m_importer;
        WebQueryCSBWidget *m_widget;

    };

}

#endif

==> kbibtex-trinity-14.1.5.tar.xz: kbibtex-trinity-14.1.5/src/webquerycsb.h <==
/***************************************************************************
 *   Copyright (C) 2004-2009 by Thomas Fischer                             *
 *   fischer@unix-ag.uni-kl.de                                             *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/
#ifndef KBIBTEXWEBQUERYCSB_H
#define KBIBTEXWEBQUERYCSB_H

#include <tdeio/job.h>

#include "fileimporterbibtex.h"
#include "webquery.h"

class TQSpinBox;
class TQCheckBox;

class KLineEdit;
class KComboBox;

namespace KBibTeX
{
    /**
     @author Thomas Fischer <fischer@unix-ag.uni-kl.de>
    */
    class WebQueryCSBWidget : public WebQueryWidget
    {
        TQ_OBJECT
    public:
        WebQueryCSBWidget( TQWidget *parent, const char *name = 0 );

        KComboBox *comboBoxField;
        TQCheckBox *checkBoxYear;
        KComboBox *comboBoxYear;
        TQSpinBox *spinBoxYear;
        KComboBox *comboBoxSortBy;
        TQCheckBox *checkBoxOnlinePapersOnly;

    protected:
        virtual void init();

    private slots:
        void slotYearCheckToggled();
    };


    /**
     @author Thomas Fischer <fischer@unix-ag.uni-kl.de>
    */
    class WebQueryCSB : public WebQuery
    {
        TQ_OBJECT
    public:
        WebQueryCSB( TQWidget* parent );
        virtual ~WebQueryCSB();

        void query();

        TQString title();
        TQString disclaimer();
        TQString disclaimerURL();

        WebQueryWidget *widget();

    protected:
        void cancelQuery() { /* nothing */ };

    private:
        BibTeX::FileImporterBibTeX *m_importer;
        WebQueryCSBWidget *m_widget;

    };

}

#endif
